#
# spec file for package sisu-mojos
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global reltype milestones
Name:           sisu-mojos
Version:        0.9.0.M3
Release:        2.3
Summary:        Sisu plugin for Apache Maven
License:        EPL-1.0 AND EPL-2.0
Group:          Development/Libraries/Java
URL:            https://www.eclipse.org/sisu
Source0:        https://github.com/eclipse-sisu/sisu-project/archive/refs/tags/%{reltype}/%{version}.tar.gz#/sisu-project-%{version}.tar.gz
Patch1:         sisu-no-dependency-on-glassfish-servlet-api.patch
Patch3:         sisu-osgi-api.patch
Patch4:         sisu-reproducible-index.patch
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.shared:maven-common-artifact-filters)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.eclipse.sisu:org.eclipse.sisu.inject) >= %{version}
BuildRequires:  mvn(org.slf4j:slf4j-nop)
BuildRequires:  mvn(org.sonatype.plexus:plexus-build-api)
#!BuildIgnore:  maven-javadoc-plugin
#!BuildIgnore:  maven-javadoc-plugin-bootstrap
BuildArch:      noarch

%description
The Sisu Plugin for Maven provides mojos to generate
META-INF/sisu/javax.inject.Named index files for the Sisu container.

%package javadoc
Summary:        API documentation for %{name}

%description javadoc
This package contains %{summary}.

%prep
%setup -q -n sisu-project-%{reltype}-%{version}

%patch -P 1 -p1
%patch -P 3 -p1
%patch -P 4 -p2

%pom_remove_plugin -r :maven-enforcer-plugin
# it is scope "import" but used only for tests that we don't run
%pom_remove_dep :junit-bom

pushd org.eclipse.sisu.mojos
%pom_add_dep org.eclipse.sisu:org.eclipse.sisu.plexus:%{version}
%pom_add_plugin org.apache.maven.plugins:maven-resources-plugin:3.3.1
%{mvn_alias} : org.sonatype.plugins:
popd

%build
pushd org.eclipse.sisu.mojos
%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8
popd

%install
pushd org.eclipse.sisu.mojos
%mvn_install
popd
%fdupes -s %{buildroot}%{_javadocdir}

%files -f org.eclipse.sisu.mojos/.mfiles
%dir %{_javadir}/%{name}
%license LICENSE.txt

%files javadoc -f org.eclipse.sisu.mojos/.mfiles-javadoc
%license LICENSE.txt

%changelog
* Wed Jun  5 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream milestone 0.9.0.M3
  * Changes
    + Annotate new method
    + Update workflow to run on Java 21
    + Build with final Java 21 on GitHub
    + Switch to JUnit5
    + Disable annotation processor by default
    + Do not silently fail in case of class scanning exceptions
    + Formatting issues
    + Update to ASM 9.7
    + Update CONTRIBUTING.md
    + Align Plexus ASM version
    + Rename release profile
    + Fix Jacoco coverage repots in Sonar
    + Add a method to allow LifecycleManager to free keys
    + Licence change: From EPL1 to EPL2
    + update documentation for exposed core extensions, fix anchors
    + Trigger Sonarcloud analysis from GHA
- Build sisu-mojos as a second spec within sisu package, since the
  sources of sisu-mojos, sisu-inject and sisu-plexus were joined in
  the same upstream project
* Tue Sep 19 2023 Fridrich Strba <fstrba@suse.com>
- Do not require maven-javadoc-plugin that we don't use
* Wed Sep  6 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to 0.9.0 milestone 2
  * Changes of 0.9.0.M2
    + Add m2e support
    + Convert APT to MD
    + Update plugin
    + Align to latest Maven plugins
  * Changes of 0.9.0.M1
    + On debug, emit scanned entries
    + Enable Java CI workflow
    + Enable CodeQL analysis
    + Avoid rewriting the index if it has not changed
  * Changes of 0.3.5
    + Build against CDI API 1.2
  * Changes of 0.3.4
    + Reproducible builds
  * Changes of 0.3.3
    + Lifecycle maintenance
  * Changes of 0.3.2
    + Java9+Jigsaw support
* Fri May  5 2023 Fridrich Strba <fstrba@suse.com>
- Initial packaging with version 0.3.1
